# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/dreamai_dl',
                'doc_host': 'https://HamzaFarhan.github.io',
                'git_url': 'https://github.com/HamzaFarhan/dreamai_dl',
                'lib_path': 'dreamai_dl'},
  'syms': { 'dreamai_dl.core': { 'dreamai_dl.core.SLModel': ('core.html#slmodel', 'dreamai_dl/core.py'),
                                 'dreamai_dl.core.SLModel.__init__': ('core.html#slmodel.__init__', 'dreamai_dl/core.py'),
                                 'dreamai_dl.core.SLModel._shared_step': ('core.html#slmodel._shared_step', 'dreamai_dl/core.py'),
                                 'dreamai_dl.core.SLModel.configure_optimizers': ( 'core.html#slmodel.configure_optimizers',
                                                                                   'dreamai_dl/core.py'),
                                 'dreamai_dl.core.SLModel.forward': ('core.html#slmodel.forward', 'dreamai_dl/core.py'),
                                 'dreamai_dl.core.SLModel.test_step': ('core.html#slmodel.test_step', 'dreamai_dl/core.py'),
                                 'dreamai_dl.core.SLModel.training_step': ('core.html#slmodel.training_step', 'dreamai_dl/core.py'),
                                 'dreamai_dl.core.SLModel.validation_step': ('core.html#slmodel.validation_step', 'dreamai_dl/core.py')},
            'dreamai_dl.data': { 'dreamai_dl.data.SLDataModule': ('data.html#sldatamodule', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.SLDataModule.__init__': ('data.html#sldatamodule.__init__', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.SLDataModule.prepare_data': ('data.html#sldatamodule.prepare_data', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.SLDataModule.setup': ('data.html#sldatamodule.setup', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.SLDataModule.test_dataloader': ( 'data.html#sldatamodule.test_dataloader',
                                                                                   'dreamai_dl/data.py'),
                                 'dreamai_dl.data.SLDataModule.train_dataloader': ( 'data.html#sldatamodule.train_dataloader',
                                                                                    'dreamai_dl/data.py'),
                                 'dreamai_dl.data.SLDataModule.val_dataloader': ( 'data.html#sldatamodule.val_dataloader',
                                                                                  'dreamai_dl/data.py'),
                                 'dreamai_dl.data.SLDataset': ('data.html#sldataset', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.SLDataset.__getitem__': ('data.html#sldataset.__getitem__', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.SLDataset.__init__': ('data.html#sldataset.__init__', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.SLDataset.__len__': ('data.html#sldataset.__len__', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.SLDataset.get_at_index': ('data.html#sldataset.get_at_index', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.SLDataset.get_img': ('data.html#sldataset.get_img', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.SLDataset.get_img_name': ('data.html#sldataset.get_img_name', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.SLDataset.get_img_path': ('data.html#sldataset.get_img_path', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.SLDataset.get_label': ('data.html#sldataset.get_label', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.SLDataset.get_tensor': ('data.html#sldataset.get_tensor', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.StatsDataset': ('data.html#statsdataset', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.StatsDataset.__getitem__': ('data.html#statsdataset.__getitem__', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.StatsDataset.__init__': ('data.html#statsdataset.__init__', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.StatsDataset.__len__': ('data.html#statsdataset.__len__', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.get_data_stats': ('data.html#get_data_stats', 'dreamai_dl/data.py'),
                                 'dreamai_dl.data.split_df': ('data.html#split_df', 'dreamai_dl/data.py')},
            'dreamai_dl.imports': {},
            'dreamai_dl.utils': { 'dreamai_dl.utils.UnNormalize': ('utils.html#unnormalize', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.UnNormalize.__init__': ('utils.html#unnormalize.__init__', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.del_norm': ('utils.html#del_norm', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.freeze_model': ('utils.html#freeze_model', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.freeze_params': ('utils.html#freeze_params', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.get_norm': ('utils.html#get_norm', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.get_norm_id': ('utils.html#get_norm_id', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.is_frozen': ('utils.html#is_frozen', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.is_norm': ('utils.html#is_norm', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.is_sequential': ('utils.html#is_sequential', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.is_tensor': ('utils.html#is_tensor', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.is_unfrozen': ('utils.html#is_unfrozen', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.params': ('utils.html#params', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.plot_loss_and_acc': ('utils.html#plot_loss_and_acc', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.plt_show': ('utils.html#plt_show', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.show_img': ('utils.html#show_img', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.tensor_to_img': ('utils.html#tensor_to_img', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.unfreeze_model': ('utils.html#unfreeze_model', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.unfreeze_params': ('utils.html#unfreeze_params', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.update_norm': ('utils.html#update_norm', 'dreamai_dl/utils.py')}}}
